<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>System Monitor</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load average</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Processes</source>
        <translation type="unfinished">Processes</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OS type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>active</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>reloading</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inactive</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>failed</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>activating</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>deactivating</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>not-found</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>bad-setting</translation>
    </message>
    <message>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>merged</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>masked</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>loaded</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>enabled</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>disabled</translation>
    </message>
    <message>
        <source>static</source>
        <translation>static</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transient</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirect</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>enabled-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>masked</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>generated</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>running</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>exited</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>reload</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>failed</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished">Active</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Ending this process may cause data loss.
Are you sure you want to continue?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>End process</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Force ending this process may cause data loss.
Are you sure you want to continue?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Force ending this application may cause data loss.
Are you sure you want to continue?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation type="unfinished">Force End</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation type="unfinished">End</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Command line</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Start time</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Click the application you want to end</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Not enabled</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Total Received</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Total Sent</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disks</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Very high</translation>
    </message>
    <message>
        <source>High</source>
        <translation>High</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Low</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Very low</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Custom</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Invalid</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Failed to change process priority</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>My processes</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>All processes</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Loading</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Failed to pause process</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Failed to resume process</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Failed to kill process</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Failed in sending signal to process</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 applications and %2 processes are running)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>No response</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tray</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>View command location</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>End process</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Resume process</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Kill process</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Change priority</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspend process</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Custom Priority</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation type="unfinished">Change</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priority</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Failed to set service startup type</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: Failed to set service startup type due to the crashed sub process.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Service instance name</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Refresh</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Restart</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Startup type</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Load</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Active</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Startup Type</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Force end application</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expand</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compact</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Services</translation>
    </message>
</context>
</TS>
